;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;;  SwiFCoIBM - Individual-Based Swine Fever Community Model (based on model versions published in Kramer-Schadt et al. 2009 and Lange et al. 2012)                                                         ;;
;;                                                                                                                                                                                                          ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;;  The model is composed of two major components:                                                                                                                                                          ;;
;;    (1) a wild boar demography model considering seasonal reproduction, herd splitting (dispersal) and mortality and                                                                                      ;;
;;    (2) a Classical Swine Fever (CSF) virus model operating on the emerging wild boar population.                                                                                                         ;;
;;                                                                                                                                                                                                          ;;
;;  Wild boar population density and structure are affected by the disease via virus-induced mortality and litter size depression.                                                                          ;;
;;  The crucial model entity is the wil boar individual, characterised by age in weeks (one week represents the approx. CSF incubation time; Artois et al. 2002, Moenning et al. 2003),                     ;;
;;    resulting in age classes piglets (age <= 8 months), yearlings (subadults; 8 months < age <= 2 years) and adults (age > 2 years).                                                                      ;;
;;  Each host has a location, which denotes its home range cell and the individual's family group.                                                                                                          ;;
;;                                                                                                                                                                                                          ;;
;;  The model landscape is represented by a grid of 4 km^2 square cells which each encompass a wild boar family group's home range (Leaper et al. 1999).                                                    ;;
;;  Each habitat cell is characterised by a breeding capacity (quality), denoting habitat quality by the number of female boars that are allowed to breed, representing density regulation in the model.    ;;
;;                                                                                                                                                                                                          ;;
;;  The program does not produce any file output; BehaviorSpace was used instead.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;;  STATE VARIABLES                                                                                                                                                                                         ;;
;;                                                                                                                                                                                                          ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


; NAME                            TYPE/RANGE     DEFAULT        DESCRIPTION

globals
[
  habitat                     ;   [set]          -              habitat cells (cells with quality > 0)
  matrix                      ;   [set]          -              matrix cells (cells with quality = 0)
  ;year_release               ;   [#]            6              year in which an randomly individual becomes infected (range of week_release)
  week_release                ;   [#]            261-312        random week in year_release of virus release following an expontential distribution with lambda = 1.5
  ;herd_prop                  ;   [%]            100            proportion of habitat patches occupied by herds
  ;release_fct                ;   [#, >=1]       3              multiplies breeding capacity of each occupied patch to determine number of boars
  max_age                     ;   [#]            572 weeks      maximum age in weeks
  ;longevity                  ;   [#]            11 years       maximum age in years (max_age / 52)
  ;age_blur                   ;   [#]            6 weeks        stochastic deviation from age class thresholds in weeks (in both directions (age class threshold +/- age_blur) following a normal distribution
  ;dist_disp                  ;   [#]            3 cells        dispersal distance for subadults
  survival_prob               ;   [%]            0.65           annual survival rate of adults and subadults (mean = 0.65, min = 0.4)
  survival_prob_pig           ;   [%]            0.5            annual survival rate of piglets (mean = 0.5, min = 0.1)
  ;case_fatality              ;   [%]            0.8            general risk for getting lethally infected by a disease transmission
  ;beta_within                ;   [#, 0-1]       0.0208         transmission coefficient within the herd
  ;beta_between               ;   [#, 0-1]       0.00208        transmission coefficient between herds
  ;fetal_inf                  ;   [#, 0-1]       0.5            probability of pre-natal infection
  ;fert_red                   ;   [#, 0-1]       0.625          reduction in fertility of infected females
  ;mue                        ;   [#]            3 weeks        mean of exponential survival time distribution for lethally infected individuals
  ;t_trans                    ;   [#]            1 week         infectious period of transiently infected individuals
  ;t_anti                     ;   [#]            15 weeks       maximum persistence of maternal antibodies (Depner et al. 2000)
  repro_prob                  ;   [#]            list           monthly reproduction probability
  week                        ;   [#, 1-52]      0              current week of the year
  ;run_years                  ;   [#]            100            number of simulated years during one run
  ;fem_prob                   ;   [%]            0.5            sex ratio (0: only males; 1: only females)
  new_leth                    ;   [#]            0              number of individuals which got lethally infected during this timestep
  new_trans                   ;   [#]            0              number of individuals which got transient infected during this timestep
  list_n_max                  ;   [list]         []             input data: sums of the number of patches adjacent to each patch in a circle of the same area as the infected/infectious area (see Report_Fragmentation)
  list_repro                  ;   [list]         []             input data: cumulative reproduction probabilities for each month
  ;seed                       ;   [#]            -              seed used if seed_setup = "ON"
  DONE                        ;   [boolean]      0              1 if stop conditions are TRUE

  ;; OUTPUT
  runtime                     ;   [min]          0              counting minutes since starting setup
  dist_inf                    ;   [cells]        0              maximum spatial distance of disease transmission
  inf_x                       ;   [#]            -              coordinate x of the pathogen-introduced cell
  inf_y                       ;   [#]            -              coordinate y of the pathogen-introduced cell
  week_inf_max                ;   [#]            -              week when infection reached other side of the tubus
  week_last                   ;   [#]            -              week in which the last infected individual was noted
  list_pop_struc              ;   [list]         []             current age class distribution of all individuals in years
  list_inf_struc              ;   [list]         []             current age class distribution of infected individuals (epi_stat = esLeth or esTrans) in years
  list_trans_struc            ;   [list]         []             current age class distribution of transient infected individuals (epi_stat = esTrans) in years
  list_leth_struc             ;   [list]         []             current age class distribution of lethally infected individuals (epi_stat = esLeth) in years
  list_mue_curr               ;   [list]         []             current infectious periods of lethally infected individuals (epi_stat = esLeth) in weeks
  list_mue_all                ;   [list]         []             all infectious periods of lethally infected individuals (epi_stat = esLeth) in weeks
]

turtles-own
[
  age                         ;   [#, 0-max_age] -              individual age in weeks
  is_female                   ;   [boolean]      -              individual sex: female or male
  herd_id                     ;   [#]            -              herd membership
  inf_id                      ;   [#]            -              patch id were the infeciton took place
  family                      ;   [#]            -              [who] of mother
  ind_case_fatality           ;   [%]            ind.           individual mortality rate (case_fatality ^ 2 for adults, sqrt case_fatality for Juveniles)
  age_group                   ;   [string]       -              age group turtle belongs to: piglet, subadult, adult; differs between sexes
  dem_stat                    ;   [string]       dsResident     demographic status: dsResident, dsOffspring, dsDispF, dsRoaming, dsDispM_subadult
  epi_stat                    ;   [string]       esSusc         epidemiological status: esSusc, esTrans, esLeth, esImm, esImmMat
  is_shedding                 ;   [boolean]      0              1 if the individual is infected (epi_stat = esTrans or esLeth
  tick_inf                    ;   [#]            -              week of infection
  tick_leth                   ;   [#]            -              week of death after infection (for epi_stat = "esLeth")
  ind_b_move                  ;   [#, 0-1]       b_move/dist    individual transmission probabilities for ranging individuals based on movement steps of current week (~time spent per cell)
  breed_prob                  ;   [#, 0-1]       -              random number for stochastic effects in monthly reproduction for the given year
  tick_birth                  ;   [#]            -              week of birth
  is_matAB                    ;   [boolean]      0              1 if mother had anti bodies (= was immune)
  is_mother                   ;   [boolean]      0              1 if female had offspring in current year
  is_breeder                  ;   [boolean]      0              1 if female is allowed to breed in current year
]

patches-own
[
  is_occupied                 ;   [boolean]      0              1 if a patch contains a herd of wild boars
  quality                     ;   [#]            [0-9]          habitat quality in terms of breeding capacity = number of females alllowed to breed
  quality_int                 ;   [#]            [0-9]          round-up value of habitat quality (ceiling quality)
  is_habitat                  ;   [boolean]      0              true if quality > 0
  qual_around                 ;   [#]            [0-9]          summed habitat quality of surrounding cells (to decide if movement is possible)
  capacity                    ;   [#]            [0-40]         overall capacity = quality * (mean number of 20 boars per cell / mean quality) = quality * (20 / 4.5) = 4.4445 boars per quality unit
  dens_rel                    ;   [#]            -              relative density of the cell (count turtles-here / capacity)
  count_inf                   ;   [#]            0              number of infectious indiviuals in this habitat cell
  inf_press                   ;   [#]            0              infection pressure based on infected indivudals in and around this patch
  is_infectious               ;   [boolean]      0              1 if patch is infected at the current step
  is_infected                 ;   [boolean]      0              1 if patch has been infected during simulation
  ind_sum                     ;   [#]            0              count of individuals per cell during the first year
  inf_sum                     ;   [#]            0              keeps track of how many times a patch contained one or more infected individuals
  count_disp_fem              ;   [#]            0              number of female dispersers per cell
  count_group                 ;   [#]            0              number of individuals belonging to the group (individuals per cell without adult males)
  disp_cells                  ;   [set]          -              cells in dispersal distance of the focal cell
  id                          ;   [#]            0              id of the cluster of same quality that this cell belongs to
]

extensions [profiler]


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                                                                           ;;
;;  SETUP + GO PROCEDURES                                                                                                                                                                                                                                    ;;
;;                                                                                                                                                                                                                                                           ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; SETUP _____________________________________________________________________________________________________________________________________________________________________________________________________

to Setup

  ca
  reset-ticks

  Init_Parameters
  Init_Landscape
  Init_Population

end


;; GO ________________________________________________________________________________________________________________________________________________________________________________________________________

to Go

  ;profiler:start

  if ticks = 0                [ reset-timer ]

  ifelse ticks mod 52 = 0     [ set week 1 ] [ set week week + 1 ]

  if ticks = week_release - 1 [ Disease_Release ]  ;; - 1 to be synchronous with week of the year

  if ticks >= week_release    [ Disease_Transmission ]

  if week = 29                [ Host_Dispersal ]

                                Host_Reproduction

                                Host_Death

                                Host_Ageing

  if ticks >= week_release   [ Disease_Transition ]

                                Update

                                set runtime precision (timer / 60) 2

                                tick

  ;profiler:stop
  ;print profiler:report
  ;profiler:reset

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;;  INITALIZATION PROCEDURES                                                                                                                                                                                ;;
;;                                                                                                                                                                                                          ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; SET PARAMETERS ____________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Set all parameters needed for initalisation and prepare output lists.

to Init_Parameters

  if seed_setup = "ON" [ random-seed seed ]
  if seed_setup = "BS"
  [
    set seed behaviorspace-run-number mod 200 + 1  ;; 200 runs per combination
    random-seed seed
  ]

  set max_age longevity * 52
  set week 0
  set week_release ((year_release - 1) * 52) + random 52 + 1
  set dist_inf 0
  set week_inf_max 0
  set list_repro [ 0.06    ;; January
                   0.16    ;; February
                   0.39    ;; March
                   0.73    ;; April
                   0.8     ;; May
                   0.88    ;; June
                   0.94    ;; July
                   0.97    ;; August
                   1.0     ;; September
                   0.0     ;; October
                   0.0     ;; November
                   0.0 ]   ;; December

  ;; OUTPUT
  set list_inf_struc []
  set list_trans_struc []
  set list_leth_struc []
  set list_mue_curr []
  set list_mue_all []

end


;; CREATE LANDSCAPE __________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Create a homogeneous or heterogeneous landscape.
  ;; The darker the color is, the higher is the breeding capacity of the home range.

to Init_Landscape

  if scenario = "homogeneous" [ ask patches [ set quality 4.5 ] ]
  if scenario = "random"      [ ask patches [ set quality random-float (2 * 4.5) ] ]

  ;; create outbreak patch with mean quality to ensure same local conditions per run
  ask patch (max-pxcor / 2) max-pycor [ set quality 4.5 ]

  set habitat patches with [quality > 0]
  set matrix patches with [quality <= 0]
  ask patches [ set quality_int ceiling quality]  ;; e.g. 5 is the range from more than 4 to 5

  ask habitat
  [
    set capacity (quality * (20 / 4.5))   ; quality * (mean number of 20 boars per cell / mean quality) = 4.4445 boars per quality unit
    set disp_cells habitat in-radius dist_disp
    set qual_around sum [quality] of neighbors
    set is_habitat 1
  ]
  ask matrix [ set capacity 0 ]

end

;; CREATE START POPULATION ___________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; One wild boar and its herd is allocated to each habitat patch, group size is initialised as three times breeding capacity (quality) of each patch.
  ;; Initial age distributions are taken from the results of a 100 years model run conducted by Kramer-Schadt et al. 2009.

to Init_Population

  crt (herd_prop / 100 * count habitat)
  [
     set age 0
     set dem_stat "dsStart"
     set epi_stat "esSusc"
     set is_shedding 0
     set is_breeder 0
     set is_mother 0
  ]

  let temp_herd_id 1

  while [ any? turtles with [dem_stat = "dsStart"] ]
  [
    ask turtles with [herd_id = 0]
    [
      move-to one-of habitat with [is_occupied = 0]
      set temp_herd_id temp_herd_id + 1
      set herd_id temp_herd_id
      set dem_stat "dsResident"
      let offspring (release_fct * quality - 1)
      hatch offspring
      if random-float 1 < (offspring - floor(offspring)) [ hatch 1 ]
      set is_occupied 1 ;patches-own
  ] ]

  while [ any? turtles with [age = 0] ]
  [
    ask turtles with [age = 0]
    [
      ifelse random-float 1 <= fem_prob [ set is_female 1 ] [ set is_female 0 ]
      let rand random-float 1
      ;; generate variation in age of start population
      let Var round random-normal 0 (age_blur / 2)
      if Var <= age_blur AND Var >= (- age_blur)
      [
        ;; intial age distribution based on Kramer-Schadt et al. 2009
        if rand <= 0.38                 [set age  52 + Var]
        if rand > 0.38 AND rand <= 0.62 [set age 104 + Var]
        if rand > 0.62 AND rand <= 0.77 [set age 156 + Var]
        if rand > 0.77 AND rand <= 0.86 [set age 208 + Var]
        if rand > 0.86 AND rand <= 0.92 [set age 260 + Var]
        if rand > 0.92 AND rand <= 0.95 [set age 312 + Var]
        if rand > 0.95 AND rand <= 0.97 [set age 364 + Var]
        if rand > 0.97 AND rand <= 0.98 [set age 416 + Var]
        if rand > 0.98 AND rand <= 0.99 [set age 468 + Var]
        if rand > 0.99 AND rand <= 1    [set age 520 + Var]
      ]

      ;; age classes males
      if age <= 21 AND is_female = 0 [ set age_group "piglet" ]
      if age > 21 AND age <= 104 AND is_female = 0 [ set age_group "subadult" ]
      if age > 104 AND is_female = 0
      [
        set age_group "adult"
        set dem_stat "dsRoaming"
      ]

      ;; age classes females
      if age <= 34 AND is_female = 1 [ set age_group "piglet" ]
      if age > 34 AND age <= 52 AND is_female = 1 [ set age_group "subadult" ]
      if age > 52 AND is_female = 1 [ set age_group "adult" ]
  ] ]

;; OUTPUT
  set list_pop_struc []
  ask turtles [ set list_pop_struc fput age list_pop_struc ]
  set list_pop_struc map [ ?1 -> ?1 / 52 ] list_pop_struc

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;;  GO PROCEDURES                                                                                                                                                                                           ;;
;;                                                                                                                                                                                                          ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  DISEASE PROCEDURES                                                                                                                                                                                      ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; DISEASE RELEASE ___________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; One wild boar group (cell) in the middle of the top row gets lethally infected in a random week ("week_release") of a given year (based on input "year_release").

to Disease_Release

  ask patch (max-pxcor / 2) max-pycor
  [
    set inf_x pxcor
    set inf_y pycor
    ask turtles-here [ Disease_Infection ]
  ]

end


;; DISEASE TRANSMISSION ______________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; First, infection pressure is calculated for all habitat cells based on infected indivudals in the herd and the eight herds surrounding the home range cell.
  ;; Afterwards, the model iterates over all individuals and stochastically sets susceptible indivudals to infected if a drawn random number (0-1) is smaller than the infection pressure of the cell.
  ;; The transmission parameter was reversly fitted to the estimated disease spread velocity of approx. 8 km per quarter (Rossi et al. 2010).
  ;; The transmission probabilities were assigned constant as 0.0208 within a herd and 0.00208 between herds.
  ;; Based on the case fatality rate (case_fatality), on infection the host is stochastically assigned either as lethally infected (esLeth) or transiently infected (esTrans).
  ;; case_fatality for lethally infected individuals applies unchanged for yearlings (subadults), is decreased for adults (case_fatality ^ 2) and increased for piglets (sqrt case_fatality)
  ;;   to represent age-dependent disease outcomes (Dahle & Liess 1992).
  ;; Lethally infected hosts receive their individual infectious period / survival times (in weeks) which are drawn from an exponential distribution with mean mue (resulting in tick_leth).

to Disease_Transmission

  set new_leth 0
  set new_trans 0

  ;; update infection status of cells
  ask habitat [ set is_infectious 0 ]

  ;; count infected individuals
  ask habitat [ set count_inf count turtles-here with [is_shedding = 1] ]

  ;; calculate infection pressure per cell
  ask habitat [ set inf_press (1 - (1 - beta_within) ^ count_inf * (1 - beta_between) ^ sum [count_inf] of neighbors) ]

  ;; stochastic infeciton based on infection pressure
  ask turtles with [dem_stat != "dsRoaming" AND epi_stat = "esSusc" ] [ if random-float 1 < [inf_press] of patch-here [ Disease_Infection ] ]

end


;; DISEASE STATE TRANSITION __________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Transient shedders (esTrans) are converted to immune (esImm) after t_trans.
  ;; Individuals protected by maternal antibodies (esImmMat) turn suscpetible (esSusc) after reaching the maximum duration of immunity of 12 weeks.

to Disease_Transition

  ;; transient infecteds
  ask turtles with [epi_stat = "esTrans" AND tick_inf + t_trans <= ticks]
  [
    set epi_stat "esImm"
    set is_shedding 0
  ]
  ;; maternally protected pigs
  ask turtles with [epi_stat = "esImmMat" AND age >= t_anti]
  [
    set epi_stat "esSusc"
    set is_matAB 0
  ]

  ask turtles with [is_matAB = 1 AND age > t_anti - 4]   ;; 1 month with varying immunity for piglets
  [
    if random-float 1 < 0.5
    [
      set epi_stat "esSusc"
      set is_matAB 0
  ] ]

  ;; OUTPUT
  set list_inf_struc []
  ask turtles with [is_shedding = 1]  [ set list_inf_struc fput age list_inf_struc ]
  set list_inf_struc map [ ?1 -> ?1 / 52 ] list_inf_struc

  set list_trans_struc []
  ask turtles with [epi_stat = "esTrans"]  [ set list_trans_struc fput age list_trans_struc ]
  set list_trans_struc map [ ?1 -> ?1 / 52 ] list_trans_struc

  set list_leth_struc []
  ask turtles with [epi_stat = "esLeth"]  [ set list_leth_struc fput age list_leth_struc ]
  set list_leth_struc map [ ?1 -> ?1 / 52 ] list_leth_struc

end


;; INFECTIOUS PROCESS ________________________________________________________________________________________________________________________________________________________________________________________
  ;; turtle procedure
  ;; Individual infection based on case fatality

to Disease_Infection

  if epi_stat = "esSusc" AND age_group = "piglet"   [ set ind_case_fatality sqrt case_fatality ]
  if epi_stat = "esSusc" AND age_group = "subadult" [ set ind_case_fatality case_fatality ]
  if epi_stat = "esSusc" AND age_group = "adult"    [ set ind_case_fatality case_fatality ^ 2 ]

  ifelse random-float 1 <= ind_case_fatality
  [
    set epi_stat "esLeth"
    set is_shedding 1
    set tick_inf ticks + 1
    set tick_leth ticks + 1 + floor (- (mue - 0.5) * ln random-float 1)
    set list_mue_all fput (tick_leth - ticks) list_mue_all  ;; list for lethally infected individuals only
    set new_leth new_leth + 1
    set is_infectious 1  ;patches-own
    set is_infected 1  ;patches-own
    if distancexy inf_x inf_y > dist_inf [ set dist_inf distancexy inf_x inf_y ]  ;patches-own
  ][ ; else
    set epi_stat "esTrans"
    set is_shedding 1
    set tick_inf ticks + 1
    set new_trans new_trans + 1
    set is_infectious 1  ;patches-own
    set is_infected 1  ;patches-own
    if distancexy inf_x inf_y > dist_inf [ set dist_inf distancexy inf_x inf_y ]  ;patches-own
  ]

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;  HOST PROCEDURES                                                                                                                                                                                         ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; REPRODUCTION ______________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Adult and subadult females reproduce only once a year depending on their age class.
  ;; In the first week of the year females are checked wether they are able breed (age + no piglets) and if there is at least one reproducible male within their range (> 2 years).
  ;; Litter size is drawn from a truncated normal distribution and reduced to a constant fraction for infected individuals.
  ;; Depending on the disease state of breeding indiviuals its piglets disease states are adjusted.

to Host_Reproduction

  ;; at the beginning of each year check... (age-based hierarchy)
  if week = 1
  [
    ;; ... for habitat patches with at least one male to reproduce ...
    ask habitat
    [
      ;; ... and for all females which can breed
      let fems count turtles-here with [is_female = 1 AND is_mother = 0 AND age > 34]
      ;; if number of potential breeders is higher than breeding capacity
      let qual_rand quality_int
      if random-float 1 < (quality - floor(quality)) [ set qual_rand floor quality ]
      if (fems > qual_rand)
      [
        ;; … sort breeders descending by age …
        let fems_sort sort-on [(- age)] turtles-here with [is_female = 1 AND is_mother = 0 AND age > 34]
        set fems qual_rand
        if length fems_sort > 0
        [
          while [ fems > 0 ]
          [
            ;; … and let num-fem of them (difference between capacity and number of breeders) reproduce
            ask first fems_sort
            [
              set is_breeder 1
              set breed_prob random-float 1
            ]
            set fems_sort remove-item 0 fems_sort
            set fems (fems - 1)
      ] ] ]

      ;; if number of breeders is equal or below than breeding capacity all breeders reproduce
      if (fems > 0 AND fems <= qual_rand)
      [
        ask turtles-here with [is_female = 1 AND age_group = "adult" AND is_mother = 0]
        [
          set is_breeder 1
          set breed_prob random-float 1
  ] ] ] ]

  ;; cumulative reproduction probabilities for each month (January to September)
  ifelse week <= 4 [ set repro_prob item 0 list_repro  Host_ProbRepro ][
    ifelse week <= 8 [ set repro_prob item 1 list_repro  Host_ProbRepro ][
      ifelse week <= 13 [ set repro_prob item 2 list_repro  Host_ProbRepro ][
        ifelse week <= 17 [ set repro_prob item 3 list_repro  Host_ProbRepro ][
          ifelse week <= 21 [ set repro_prob item 4 list_repro  Host_ProbRepro ][
            ifelse week <= 26 [ set repro_prob item 5 list_repro  Host_ProbRepro ][
              ifelse week <= 30 [ set repro_prob item 6 list_repro  Host_ProbRepro ][
                ifelse week <= 34 [ set repro_prob item 7 list_repro  Host_ProbRepro ][
                  ifelse week <= 39 [ set repro_prob item 8 list_repro  Host_ProbRepro ][
                    ifelse week <= 43 [ set repro_prob item 9 list_repro  Host_ProbRepro ][
                      ifelse week <= 47 [ set repro_prob item 10 list_repro  Host_ProbRepro ][
                        if week <= 52 [ set repro_prob item 11 list_repro  Host_ProbRepro
  ] ] ] ] ] ] ] ] ] ] ] ]

end

;; REPRODUCTION ______________________________________________________________________________________________________________________________________________________________________________________________
 ;; observer procedure
 ;; Sub-procedure of Host_Reproduction.

to Host_ProbRepro


    ask turtles with [is_breeder = 1]
    [
      ;; stochastic effect in probabilities of reproduction
      if breed_prob < repro_prob
      [
        let rand random-float 1

        ;; stochastic effect in number of piglets
        if (rand > 0.01305859 AND rand <= 0.082208805)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (1 * fert_red)   ;; round to integer
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
          ;; if the breeder is not infected
            hatch 1
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.082208805 AND rand <= 0.24510931)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (2 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
            ]
          ][
            ;; if the breeder is not infected
            hatch 2
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.24510931 AND rand <= 0.495050085)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (3 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
            ]
          ][
            ;; if the breeder is not infected
            hatch 3
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.495050085 AND rand <= 0.744990859)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (4 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
            ;; if the breeder is not infected
            hatch 4
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.744990859 AND rand <= 0.907891364)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (5 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
            ]
          ][
            ;; if the breeder is not infected
            hatch 5
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.907891364 AND rand <= 0.977041579)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (6 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
            ]
          ][
            ;; if the breeder is not infected
            hatch 6
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.977041579 AND rand <= 0.996144138)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (7 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
            ;; if the breeder is not infected
            hatch 7
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.996144138 AND rand <= 0.999575749)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (8 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
            ;; if the breeder is not infected
            hatch 8
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.999575749 AND rand <= 0.99997575)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (9 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
            ;; if the breeder is not infected
            hatch 9
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        if (rand > 0.99997575 AND rand <= 1.0)
        [
          ;; if the breeder is infected number of piglets is reduced
          ifelse is_shedding = 1
          [
            hatch floor (10 * fert_red)
            [
              set dem_stat "dsOffspring"
              set family who
          ] ]
          [
            ;; if the breeder is not infected
            hatch 10
            [
              set dem_stat "dsOffspring"
              set family who
        ] ] ]

        set tick_birth ticks
        set is_breeder 0
        set is_mother 1
  ] ]

  ask turtles with [dem_stat = "dsOffspring"]
  [
    ifelse random-float 1 <= fem_prob [ set is_female 1 ] [ set is_female 0 ]
    set age 0
    set age_group "piglet"
    set is_breeder 0

    ;; Susceptibles
    if [epi_stat] of turtle family = "esSusc"
    [
      set dem_stat "dsResident"
      set epi_stat "esSusc"
      set is_shedding 0
    ]

    ;; Immunes
    if [epi_stat] of turtle family = "esImm"
    [
      set dem_stat "dsResident"
      set epi_stat "esImmMat"
      set is_shedding 0
      set is_matAB 1
    ]

    ;; Infecteds
    if [is_shedding] of turtle family = 1
    [
      ifelse random-float 1 < fetal_inf
      [
        set dem_stat "dsResident"
        set epi_stat "esLeth"
        set is_shedding 1
        set tick_inf ticks + 1
        set tick_leth ticks + 1 + floor (- (mue - 0.5) * ln random-float 1)
        set new_leth new_leth + 1
        set list_mue_all fput (tick_leth - ticks) list_mue_all
      ][
        set dem_stat "dsResident"
        set epi_stat "esSusc"
        set is_shedding 0
  ] ] ]

end


;; DEATH _____________________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Iterating over the entire population, each individual either stochastically dies due to age class dependent mortality rates by drawing a random number,
  ;;    due to reaching a certain maximum age or due to a lethal infection after a certain ifnection time span (tick_leth).
  ;; Baseline mortality is age-dependent and are drawn from a Gaussian distribution which was adjusted to annual survival estimates found in the literature and is cutted symmetrically around the mean.
  ;; The stochastic effect resembles 'good' versus 'bad' years for wild boars (i.e. environmental noise).
  ;; Each time step the adjusted age-dependent mortality is applied to all individual.

to Host_Death

  ;; environmental noise
  if noise = TRUE
  [
    if week = 1
    [
      let var 999
      while [ var > 1 OR var < -1 ]
      [
        set var random-normal 0 (1 / 2.576)  ;; 99% between -1 and 1
        ;; survival probability for subadults and adults
        set survival_prob 0.65 + var * (0.65 - 0.4)  ;; mean + var * (mean - min) to scale for age group
        ;; survival probability for piglets
        set survival_prob_pig 0.5 + var * (0.5 - 0.1)
  ] ] ]

  ;; survival probability for subadults and adults
  set survival_prob 0.65
  ;; survival probability for piglets
  set survival_prob_pig 0.5

  ask turtles
  [
    ;; mean survival probability for yearlings (Gaillard et al. 1987) = 0.65 = mean survival probability for adults (Focardi et al. 1996)
    ifelse age > 34 [ if random-float 1 < (1 - (survival_prob ^ (1 / 52))) [ die ] ]
                    [ if random-float 1 < (1 - (survival_prob_pig ^ (1 / 52))) [ die ] ]
  ]

  ;; mortality due to a lethal infection
  ask turtles with [epi_stat = "esLeth"] [ if tick_leth = ticks [ die ] ]

  ;; mortality due to reaching maximum age (more than 10 years)
  ask turtles with [age >= max_age] [ die ]

  ;; update occupation status of cells
  ask habitat with [not any? turtles-here AND is_occupied = 1] [ set is_occupied 0 ]

  ;;OUTPUT
  set list_pop_struc []
  ask turtles [ set list_pop_struc fput age list_pop_struc ]
  set list_pop_struc map [ ?1 -> ?1 / 52 ] list_pop_struc

end


;; AGE _______________________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; For each individual age is incremented one week and disease state transitions are performed.
  ;; Females who gave birth more than 33 weeks before can reproduce again.

to Host_Ageing

  ask turtles
  [
    set age age + 1
    ifelse age = 35
    [
      set age_group "subadult"
      if is_female = 0 [ set dem_stat "dsDispM_subadult" ]
    ][
      ifelse age = 53 AND is_female = 1
      [ set age_group "adult" ]
      [
        if age = 105 AND is_female = 0
        [
          set age_group "adult"
          if qual_around > 0 [ set dem_stat "dsRoaming" ]  ;patches-own
    ] ] ]
    if is_mother = 1 AND (tick_birth + 34) = ticks [ set is_mother 0 ]
  ]

end


;; HERD SPLITTING ____________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; During summer, subadult females either remain with their mothers or establish new territories nearby.
  ;; Herd splitting is performed in one week per year only where female subadults (8 months = 34 weeks < age <= 2 years = 104 weeks) without offspring are able to move between herds.
  ;; All herds to split are extracted matching the conditions of containing a number of females exceeding the cells carrying capacity and containing at least 2 dispersers.
  ;; For each splittable herd an habitat cell without female groups and a carrying capacity above 0 within the dispersal distance of 6 km (3 cells) is selected randomly.
  ;; All dispersers from the source cell find a new herd on that cell.

to Host_Dispersal

  let overcap habitat with [count turtles-here with [is_female = 1 AND age > 34] - quality >= 2 AND qual_around > 0]

  ask overcap
  [
    ;; count females above breeding capacity (quality)
    let num-overfem ceiling (count turtles-here with [is_female = 1 AND age > 34] - quality)
    ;; ... assign those females a disperser-status...
    let num-disp count turtles-here with [age_group = "subadult" AND is_female = 1 AND is_breeder = 0]
    ;; ... which are over breeding capacity ...
    if num-disp > num-overfem [ set num-disp num-overfem ]
    ;; ... and if there are at least 2 dispersers ...
    if num-disp >= 2
    [ ask n-of num-disp turtles-here with [age_group = "subadult" AND is_female = 1 AND is_breeder = 0] [ set dem_stat "dsDispF" ] ]
    set count_disp_fem 0
  ]

  ask overcap with [any? turtles-here with [dem_stat = "dsDispF"]]
  [
    let list_disp_f []
    ask turtles-here with [dem_stat = "dsDispF"] [ set list_disp_f fput self list_disp_f ]
    set count_disp_fem length list_disp_f   ; number of dispersing females of this cell
    let temp_disp_cells disp_cells with [not any? turtles-here with [is_female = 1]]
    ifelse count temp_disp_cells > 0
    [
      let newhabitat one-of temp_disp_cells
      while [ not empty? list_disp_f ]
      [
        ask first list_disp_f
        [
          move-to newhabitat
          set dem_stat "esResident"
          if is_shedding = 1
          [
            set is_infectious 1 ;patches-own
            set is_infected 1 ;patches-own
            if distancexy inf_x inf_y > dist_inf [ set dist_inf distancexy inf_x inf_y ] ;patches-own
          ]
          set list_disp_f remove-item 0 list_disp_f
      ] ]
      ask newhabitat [ set is_occupied 1 ]
      set list_disp_f []
    ][
      ;; else = if there are no unoccupied habitat cells within their dispersal distance the dispersers emmigrate/die
      ask turtles-here with [dem_stat = "dsDispF"]
      [
        ;; version used in Fernandez et al. 2006: dispersers stay in their maternal cell if no empty habitat cell is available
        set dem_stat "esResident"
  ] ] ]

end



;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; HELP FUNCTIONS                                                                                                                                                                                           ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;


;; UPDATE ____________________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Update variables (e.g. counts, infection status of patches, output lists) and check stop condition (DONE)

to Update

  ;; update infection status patch
  ask patches
  [
    ifelse any? turtles-here with [is_shedding = 1] [ set is_infectious 1 ]
                                                    [ set is_infectious 0 ]
  ]

  ;; check stop condition
  if ((not any? turtles with [is_shedding = 1]) OR (ticks = run_years * 52)) AND (ticks >= week_release - 1) [ set DONE 1 ]
  if DONE = 1 [ stop ]

  ;; OUTPUT
  set list_mue_curr []
  ask turtles with [epi_stat = "esLeth"] [ set list_mue_curr fput (tick_leth - ticks) list_mue_curr ]
  set week_last ticks + 1
  if week_inf_max = 0 AND (any? patches with [pycor = 0 AND is_infectious = 1]) [ set week_inf_max ticks + 1 ]

end


;; UPDATE VIEW _______________________________________________________________________________________________________________________________________________________________________________________________
  ;; observer procedure
  ;; Update GUI by coloring individuals by their healt status (epi_stat) and patches by their quality (grey = non-infectious, orange = infectious, yellow = outbreak start)

to View

  ask turtles with [epi_stat = "esSusc"] [ set color black ]
  ask turtles with [epi_stat = "esImm" OR epi_stat = "esImmMat"] [ set color 53 ]  ;; green
  ask turtles with [epi_stat = "esLeth"]
  [
    set color 14  ;; red
    set size 0.75
  ]
  ask turtles with [epi_stat = "esTrans"]
  [
    set color 45  ;; yellow
    set size 0.75
  ]
  ask patches [ set pcolor scale-color grey quality 12 0 ]
  ask habitat with [is_infectious = 1] [ set pcolor scale-color orange quality 12 0 ]
  if ticks >= week_release [ ask patch inf_x inf_y [ set pcolor 47 ] ]  ;; pale yellow

end


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;                                                                                                                                                                                                          ;;
;; END                                                                                                                                                                                                      ;;
;;                                                                                                                                                                                                          ;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@#$#@#$#@
GRAPHICS-WINDOW
916
11
1215
602
-1
-1
11.64
1
10
1
1
1
0
0
0
1
0
24
0
49
1
1
1
ticks
30.0

PLOT
8
11
353
211
Population
Time [weeks]
Number of Individuals
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot count turtles"

PLOT
8
214
353
411
Epidemiological Status (all)
Time [weeks]
Number of Individuals
0.0
10.0
0.0
100.0
true
true
"" "if not any? turtles [ stop ]"
PENS
"Susceptible" 1.0 0 -16777216 true "" "plot count turtles with [epi_stat = \"esSusc\"]"
"Immune" 1.0 0 -13210332 true "" "plot count turtles with [epi_stat = \"esImm\"]"
"Immune Mat" 1.0 0 -10899396 true "" "plot count turtles with [epi_stat = \"esImmMat\"]"
"Lethally Inf" 1.0 0 -8053223 true "" "plot count turtles with [epi_stat = \"esLeth\"]"
"Transient Inf" 1.0 0 -817084 true "" "plot count turtles with [epi_stat = \"esTrans\"]"

PLOT
686
11
909
236
Control
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
866
197
1016
215
1
11
139.9
1

TEXTBOX
691
28
905
232
i
11
139.9
0

BUTTON
695
29
750
62
Setup
Setup\nView
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
752
29
826
62
Run Week
Go\nView
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
828
29
902
62
Run Year
Go\nView
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
811
64
902
97
Run Until End
if DONE = 0 [ Go View ]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
695
64
808
97
Run Until Infection
while [ ticks + 1 < (week_release) ] [ Go View ]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
686
239
909
374
Host Population
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
690
254
904
369
i
11
139.9
0

SLIDER
693
258
795
291
herd_prop
herd_prop
0
100
100.0
1
1
NIL
HORIZONTAL

SLIDER
798
258
901
291
release_fct
release_fct
0
10
4.5
0.5
1
NIL
HORIZONTAL

SLIDER
693
294
795
327
longevity
longevity
0
50
11.0
1
1
yrs
HORIZONTAL

SLIDER
798
294
901
327
age_blur
age_blur
0
26
6.0
1
1
weeks
HORIZONTAL

PLOT
686
377
909
601
Disease Dynamics
NIL
NIL
0.0
1.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" ""

TEXTBOX
692
395
905
596
i
11
139.9
0

INPUTBOX
695
532
794
592
beta_within
0.0208
1
0
Number

INPUTBOX
798
532
901
592
beta_between
0.00208
1
0
Number

SLIDER
693
397
794
430
year_release
year_release
1
5
2.0
1
1
NIL
HORIZONTAL

SLIDER
693
434
794
467
fetal_inf
fetal_inf
0
1
0.5
0.05
1
NIL
HORIZONTAL

SLIDER
798
397
901
430
fert_red
fert_red
0.025
1
0.625
0.025
1
NIL
HORIZONTAL

INPUTBOX
798
470
848
530
t_trans
1.0
1
0
Number

INPUTBOX
851
470
901
530
t_anti
12.0
1
0
Number

INPUTBOX
695
100
784
160
run_years
12.0
1
0
Number

SLIDER
798
433
901
466
case_fatality
case_fatality
0
1
1.0
0.05
1
NIL
HORIZONTAL

MONITOR
1219
11
1269
56
Year
ceiling (ticks / 52)
0
1
11

PLOT
357
214
683
411
Age Classes of Infected Ind.
Age Class [years]
Numberof Infected Ind.
0.0
11.0
0.0
100.0
true
true
"" "if not any? turtles with [epi_stat = \"esLeth\" or epi_stat = \"esTrans\"]\n[\n  clear-plot\n  stop\n]"
PENS
"pen-0" 1.0 1 -14737633 true "" ""
"pen-1" 1.0 1 -5298144 true "" ""
"pen-2" 1.0 1 -817084 true "" ""
"pen-3" 1.0 0 -7500403 true "" ""
"oen-4" 1.0 0 -2674135 true "" ""
"Total Inf" 1.0 1 -14737633 true "" "histogram list_inf_struc"
"Lethally Inf" 1.0 1 -5298144 true "" "histogram list_leth_struc"
"Transient Inf" 1.0 1 -817084 true "" "histogram list_trans_struc"

SLIDER
798
330
901
363
dist_disp
dist_disp
0
25
3.0
1
1
NIL
HORIZONTAL

SLIDER
693
330
795
363
fem_prob
fem_prob
0
1
0.5
0.01
1
NIL
HORIZONTAL

TEXTBOX
869
413
1019
431
NIL
11
0.0
1

MONITOR
602
267
676
308
New Transient
new_trans
17
1
10

MONITOR
1219
59
1323
104
Run Time [min]
runtime
17
1
11

PLOT
357
414
683
601
Survival Time of Lethally Infected Ind.
Duration Infectious Period [weeks]
Number of Infected
0.0
20.0
0.0
10.0
true
false
"" "if not any? turtles with [epi_stat = \"esLeth\"]\n[\n  clear-plot\n  stop\n]"
PENS
"default" 1.0 1 -14737633 true "" "histogram list_mue_curr"

MONITOR
616
435
673
476
max
max(list_mue_all)
17
1
10

MONITOR
274
549
351
590
Transient Inf
count turtles with [epi_stat = \"esTrans\"]
17
1
10

MONITOR
274
509
351
550
Lethally Inf
count turtles with [epi_stat = \"esLeth\"]
17
1
10

MONITOR
274
470
351
511
Immunes
count turtles with [epi_stat = \"esImm\" or epi_stat = \"esImmMat\"]
17
1
10

MONITOR
274
431
351
472
Susceptibles
count turtles with [epi_stat = \"esSusc\"]
17
1
10

PLOT
356
11
682
211
Age Classes
Age Class [years]
Number of Individuals
0.0
11.0
0.0
10.0
true
false
"" "if not any? turtles\n[\n  clear-plot\n  stop\n]"
PENS
"default" 1.0 1 -16777216 true "" "histogram list_pop_struc"

MONITOR
558
112
619
153
Males
count turtles with [is_female = 0]
17
1
10

MONITOR
558
72
619
113
Females
count turtles with [is_female = 1]
17
1
10

MONITOR
498
32
559
73
Population
count turtles
17
1
10

MONITOR
615
112
672
153
Adults
count turtles with [age_group = \"adult\"]
17
1
10

MONITOR
615
72
672
113
Subadults
count turtles with [age_group = \"subadult\"]
17
1
10

MONITOR
602
228
676
269
New Lethal
new_leth
17
1
10

MONITOR
1273
11
1323
56
Week
week
17
1
11

MONITOR
1219
107
1323
152
Ticks per second
ticks / (runtime * 60)
1
1
11

BUTTON
787
194
902
227
Default Values
;; CONTROL\nset run_years 12\nset seed_setup \"ON\"\nset seed 1\n\n;; LANDSCAPE\nset scenario \"random\"\n\n;; HOST POPULATION\nset herd_prop 100\nset release_fct 4.5\nset longevity 11\nset age_blur 6\nset fem_prob 0.5\nset dist_disp 3\n\n;; DISEASE DYNAMICS\nset year_release 2\nset fert_red 0.625\nset fetal_inf 0.5\nset case_fatality 0.5\nset beta_within 0.0208\nset beta_between 0.00208\nset mue 4\nset t_trans 1\nset t_anti 12\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
558
32
619
73
Roamers
count turtles with [dem_stat = \"dsRoaming\"]
17
1
10

CHOOSER
787
147
902
192
seed_setup
seed_setup
"ON" "OFF" "BS"
2

SLIDER
695
470
794
503
mue
mue
1
9
9.0
1
1
NIL
HORIZONTAL

MONITOR
615
32
672
73
Piglets
count turtles with [age_group = \"piglet\"]
17
1
10

INPUTBOX
734
125
784
185
seed
1.0
1
0
Number

CHOOSER
787
100
902
145
scenario
scenario
"homogeneous" "random"
1

SWITCH
694
194
784
227
noise
noise
0
1
-1000

PLOT
9
414
354
600
Epidemiological Status (infected ind.)
Time [weeks]
Number of Infected Ind.
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"Lethally Inf" 1.0 0 -8053223 true "" "plot count turtles with [epi_stat = \"esLeth\"]"
"Transient Inf" 1.0 0 -817084 true "" "plot count turtles with [epi_stat = \"esTrans\"]"

@#$#@#$#@
# SwiFCoIBM


The classical swine fever (CSF) pathogen – wild boar host model is a combination of a spatially explicit, stochastic, agent-based model for wild boars (Sus scrofa L.) and an epidemiological model for the CSF virus interacting with the host’s life-history, thus the system or community consist of two species, with the pathogen species never occurring outside the host (no indirect transmission and survival outside alive hosts). The model has been parameterized with knowledge from field experiments and clinical studies and is documented in each of the publications mentioned below following the ODD protocol (Grimm et al., 2006, 2010).

## 1 Purpose

The original model (Kramer-Schadt et al., 2009) was used to assess intrinsic (system immanent host-pathogen interaction and host life-history) and extrinsic (spatial extent and density) factors contributing to the long-term persistence of the disease and has further been used to assess the effects of intrinsic dynamics (Lange et al., 2012a) and indirect transmission (Lange et al., 2016) on the disease course. In an applied context, the model was used to test the efficiency of spatiotemporal vaccination regimes (Lange et al. 2012b) as well as the risk of disease spread in the country of Denmark (Alban et al., 2005). 

## 2 Entities, state variables and scales

The model comprises two major components, a wild boar host demography model considering seasonal reproduction, natal dispersal (of both, subadult females and males) and mortality, and a CSF virus model operating on the boar population via within- and between-group infection. Wild boar population density and structure are inﬂuenced by the disease via virus-induced mortality and litter size depression.

The model entities are spatial units, or grid cells, and wild boars. Grid cells are characterized by habitat quality in terms of breeding capacity (*B*), i.e. the number of female boars that are allowed to have offspring (Jedrzejewska, Jedrzejewski, Bunevich, Milkowski, & Krasinski, 1997). Thereby, local host density is regulated in the model, i.e. increasing numbers of fertile females can breed only until breeding capacity is reached. A grid cell represents about 2 km × 2 km, encompassing an average home range area of a boar group (Leaper, Massei, Gorman, & Aspinall, 1999). The landscapes is heterogeneous with random distributed habitat qualities ranging between 0 and 9 breeding females.

The crucial entity, individual wild boars, are characterized by sex, age in weeks, location, demographic status (e.g. breeding, dispersing and ranging) and health status. Three age classes are distinguished: piglet (< 34 weeks), subadult (between 34 weeks and < 1 year for females and < 2 years for males) and adult. Location is defined by the grid cell the wild boar inhabits. The health status of the individuals is described by an SIR epidemiological classification (susceptible; transiently infected; lethally infected with individual infectious period; immune by surviving the infection or by maternal antibodies). Females, which are at least subadult, may be assigned as breeders according to the breeding capacity of their family group’s cell. Subadult wild boars may disperse during the dispersal period dependent on their sex and demographic status (disperser or non-disperser).

One time step corresponds to the approximate CSF incubation time of one week (Artois et al., 2002; Moennig, Floegel-Niesmann, & Greiser-Wilke, 2003) while simulations usually run for 12 years (624 weeks) with the virus being released in the second year (week 53–104) to a defined boar group to ensure the same distance to the model borders and an established spatial population structure. The model landscape consists of 100 km × 50 km (50 × 25 grid cells).

## 3 Process Overview and Scheduling 

Each time step, the following procedures are executed by the wild boars in the given order: pathogen transmission, natal dispersal of males and females, respectively, reproduction, mortality, ageing, and disease course. In the ﬁrst week of each year, females are assigned to breed. Natal dispersal of males and females was limited to week 17 and week 29 of the year, respectively.

## 4 Design concepts

### Basic principles

Both processes of the host and the pathogen are simulated with a given stochasticity which resembles natural conditions. Disease transmission for groups is modelled density-dependent (see Eq. 1 and 2). 

### Emergence

Wild boar population dynamics emerge from individual behaviour, resulting from age- and sex-dependent movement behaviours (natal dispersal) as well as age-dependent seasonal reproduction and survival probabilities. The epidemic course emerges from different virus transmission probabilities as well as individual stochastic disease courses and infectious periods.

### Adaptation

The number of breeding females per cell is determined by (a) the habitat quality of the cell and (b) the number and age of the reproductive females within the cell.

### Objectives

Dispersing individuals search for empty (unoccupied) cells (in case of female dispersers) or join other groups that are below their cells’ carrying capacity (in case of male dispersers) within their search range. 

### Learning

There is no learning implemented in our model.

### Prediction

Since the landscape structure is static there is no need to predict future environmental conditions.

### Sensing

Individuals can sense if and how many other animals are within a cell in their search range when dispersing. 

### Interaction

Based on the transmission rates, interactions between individuals might lead to virus transmission from an infected to a susceptible individual. Reproduction is density-and age-dependent with the oldest females giving birth first. Thus, if the number of reproducible females exceeds a cell’s breeding capacity, interaction leads to repressed reproduction.

### Stochasticity

Demographic and behavioural parameters are imposed via probability distributions to account for variation in the biological processes. Stochastic individual disease courses and infectious periods are modelled explicitly because variation in the disease outcome between individuals was identified to be essential for virus endemicity without reservoirs (Kramer-Schadt et al., 2009). 

### Collectives

Individuals form groups within their cell that experience density-dependent transmission probabilities. During natal dispersal, male subadults may join those groups while female subadults may form new groups.

### Observation

To evaluate model outcomes, we measured several properties of the host-virus system at each time step of the simulation. These outputs include the overall number of individuals as well as per health status (susceptible, infected, recovered) and their combinations. Furthermore, the last week of infection are recorded. From this output, duration of an outbreak as well as probability of disease persistence (i.e. the virus being present in the system until the end of simulations) can be estimated. 

## 5 Initialization

One boar family group was allocated to each cell with an average breeding capacity *B* of 4.5 females, resulting in the reported density of approximately 20 boars per cell or 5 boars per km2 (EFSA (European Food Safety Authority), 2009; Howells & Edwards-Jones, 1997; Melis, Szafranska, Jedrzejewska, & Barton, 2006; Sodeikat & Pohlmeyer, 2003). We simulated heterogeneous landscapes with a breeding capacity *B* between 0 and 9 assigned to each of the 2500 grid cells (*B* ε {0;9}). In case *B* is a floating point number, the number of individuals is determined stochastically based on the remainder. Initial age distribution was obtained from the results of a 100-year model run conducted by (Kramer-Schadt et al., 2009), the sex ratio was balanced (i.e. probability of 0.5 to be either male or female). Wild boar density reﬂects long-term average values of densely populated Central European habitats (EFSA (European Food Safety Authority), 2009; Howells & Edwards-Jones, 1997; Melis, Szafranska, Jedrzejewska, & Barton, 2006; Sodeikat & Pohlmeyer, 2003). Group size was initialised according to the cells carrying capacity Ki that is 4.5 times its breeding capacity Bi.

## 6 Input

The model does not include external input representing environmental conditions changing over time.

## 7 Submodels

### Initial infection (pathogen release)

The virus is released to the population by infection of one wild boar group (i.e. cell) in middle of the upper row of home ranges (i.e. cell with the coordinates x = 1 and y = 13) to allow for comparison between runs. The release is scheduled in a random week of the second year of the model run.

### Pathogen transmission

Virus transmission is modelled stochastically. The transmission parameter determines the weekly probability of being infected by an infectious group mate βw. Weekly infection pressure *λ_i* for each susceptible individual in cell i is determined by the probability of being infected by an infectious group mate *β_w* (within-group transmission probability) and the probability of being infected by an infectious individual in one of the eight neighbouring cells *β_e* (between-group transmission probability):
 
[1]   *λ_i = 1 - (1 - β_w )^(I_i) × (1 - β_e )^(Σ_j I_j)*

where *I_i* is the number of infectious group mates and *I_j* is the numbers of infectious hosts in the jth adjacent cell. The resulting probability value *λ_i* provides the parameter of a binomial chance process to decide whether a susceptible animal will be infected.

The transmission parameters *β_w* (and thereby *β_e* since it was ﬁxed as one tenth of *β_w*) was calibrated in order to reproduce the spreading velocity observed in France (Rossi et al., 2010) with the constant parameter value *β_w* = 0.0208 within and, hence, *β_e* = 0.00208 between groups (Kramer-Schadt et al., 2009).

CSF shows a variety of disease courses on the individual level (Depner et al., 1997; Liess, 1987). Therefore, in our model the disease course is stochastically speciﬁed for each individual. The disease course submodel is described by two parameters: individual case mortality *M* and the mean infectious period of lethally infected hosts *μ*. Upon infection the host is stochastically assigned either as lethally infected (with probability *M*) or as transiently infected (1 – *M*). *M* is age-specific (Dahle & Liess 1992): for adults the probability is decreased to *M_a* = *M*^2 and for piglets increased to *M_p* = *M* while it is unchanged for yearlings *M_y* = *M*. Transiently infected wild boars ﬁrst pass through an infectious period of one week and subsequently becomes non-infectious and gain life-long immunity (Artois et al. 2002; Moennig, Floegel-Niesmann, & Greiser-Wilke, 2003; EFSA 2009). The individual infectious period (*m_i* in weeks) of lethally infected hosts is drawn from an exponential distribution with the mean speciﬁed by parameter *μ*:

[2]   *m_i = 1 + floor(-(μ-0.5) × ln(U(0,1)))*

where *U(0,1)* is a uniformly distributed random number between 0 and 1. To avoid unrealistically long infections, *m_i* was stochastically assigned until *m_i* ≤ 10 × *μ*. Lethally infected hosts remain infectious until death. Offspring from immune female breeders gets maternal antibodies and is thus immune for the first eight to twelve weeks after birth (*t_anti*). The number of weeks of immunisation due to maternal antibodies is randomly assigned for those piglets.

### Natal dispersal

Herd splitting, where subadult individuals may move together to search for or form new groups, is performed in specified weeks of the year only. The timing of these events is sex-dependent: Subadult females without offspring perform their natal dispersal in the 29th week of the year, while subadult males disperse during the 17th week. In the given week of the year, all herds to split are extracted, matching the conditions of containing at least a specified number of subadults Ndisp to move (either male or female). For female dispersal, only cells exceeding the breeding capacity *B* are evaluated. Splittable herds are iterated randomly. For each of them, a habitat cell not exceeding carrying capacity K (for males) or without any family group (for females) within a Euclidean distance ddisp is selected randomly as new cell for the group, excluding the source cell. If there is no cell fulfilling these conditions, subadults stay within their group’s cell.

### Reproduction

Females reproduce once a year, depending on their age class. Individual females, which are at least subadult, reproduce depending on the season with a peak in March and no reproduction in winter from October to December (Boitani et al. 1995). In the first week of the year, female individuals are checked for their breeding status. All females not exceeding their habitat cells breeding capacity, starting with the oldest individuals, are allowed to breed. The week of the year to breed is assigned in the first week of each year according to weekly reproduction probabilities, derived from monthly probabilities and the number of weeks in the month. Litter size is drawn from a pre-calculated truncated normal distribution (Bieber & Ruf 2005) and reduced to a constant fraction for infected individuals. Litter size of transient shedders and lethally infected hosts is multiplied with the reduction factor *α_f*.

Depending on the disease state of the breeding individual, its piglets disease states are adjusted. Susceptible individuals produce susceptible offspring, immune individuals produce immune offspring with maternal antibodies (see section “Pathogen state transition”). Transient shedders and lethally infected individuals yield offspring, each one lethally infected with a given probability of prenatal infection ppi.

### Mortality

Stochastic baseline mortality is age-dependent and adjusted to annual survival estimates found in the literature (Focardi, Toso, & Pecchioli 1996; Gaillad, Vassant, & Klein 1987). Per time step we apply the adjusted age-dependent mortality (*m_week*) to the individual:

[3]   *m_week = 1 - (s_year)^(1/52)*

In addition to the stochastic baseline mortality, each individual may die due to reaching a certain maximum age, or due to a lethal infection after a certain infection time span *m_i* (see section ”Pathogen transmission”).

### Ageing

The ageing process iterates over all individuals. For each individual *k*, age *T_k* is incremented one week and disease state transitions are performed. Females become subadult and adult at an age of 34 and 52 weeks, respectively, while males enter the subadult and adult age groups at an age of 21 and 104 week, respectively.

### Disease course (pathogen state transition)

Transient shedders convert to immune after a certain latency period *t_latent*. An individual i protected by maternal antibodies turns susceptible if reaching an age *T_i* of the protection time of *t_anti* (see section “Pathogen transmission”). After disease state transition the age of the infection is incremented by one week if the individual is not susceptible.

## References 

* Alban, L., Andersen, M.M., Asferg, T., Boklund, A., Fernandez, N., Greiner, M., Kramer-Schadt, S., Stockmarr, A., Thulke, H.-H., Uttenthal, Å., Ydesen, B. (2005). Classical swine fever and wild boar in Denmark: A risk analysis. Project Report, Danish Institute for Food and Veterinary Research DFVF. ISBN: 87-91587-01-8. 118 pages.
* Artois, M., Depner, K. R., Guberti, V., Hars, J., Rossi, S., & Rutili, D. (2002). Classical swine fever (hog cholera) in wild boar in Europe. Revue Scientifique et Technique, 21(2), 287–303. Retrieved from https://www.ncbi.nlm.nih.gov/pubmed/11974616
* Bieber, C., & Ruf, T. (2005). Population dynamics in wild boar Sus scrofa: ecology, elasticity of growth rate and implications for the management of pulsed resource consumers. The Journal of Applied Ecology, 42(6), 1203–1213. doi:10.1111/j.1365-2664.2005.01094.x
* Boitani, L., Trapanese, P., Mattei, L., & Nonis, D. (1995). Demography of a wild boar (Sus scrofa, L.) population in Tuscany, Italy. Gibier, Faune Sauvage / ONC, Office National de La Chasse, 12(2), 109–132.
* Depner, K. R., Hinrichs, U., Bickhardt, K., Greiser-Wilke, I., Pohlenz, J., Moennig, V., & Liess, B. (1997). Influence of breed-related factors on the course of classical swine fever virus infection. The Veterinary Record, 140(19), 506–507. Retrieved from https://www.ncbi.nlm.nih.gov/pubmed/9172299
* EFSA (European Food Safety Authority). (2009). Control and eradication of Classical Swine Fever in wild boar. European Food Safety Authority Journal, 932(EFSA-Q-2007-200), 1–18. Retrieved from https://efsa.onlinelibrary.wiley.com/doi/abs/10.2903/j.efsa.2009.932
* Focardi, S., Toso, S., & Pecchioli, E. (1996). The population modelling of fallow deer and wild boar in a Mediterranean ecosystem. Forest Ecology and Management, 88(1), 7–14. doi:10.1016/S0378-1127(96)03804-2
* Grimm, V., Berger, U., Bastiansen, F., Eliassen, S., Ginot, V., Giske, J., … DeAngelis, D. L. (2006). A standard protocol for describing individual-based and agent-based models. Ecological Modelling, 198(1), 115–126. doi:10.1016/j.ecolmodel.2006.04.023
* Grimm, V., Berger, U., DeAngelis, D. L., Polhill, J. G., Giske, J., & Railsback, S. F. (2010). The ODD protocol: A review and first update. Ecological Modelling, 221(23), 2760–2768. doi:10.1016/j.ecolmodel.2010.08.019
* Howells, O., & Edwards-Jones, G. (1997). A feasibility study of reintroducing wild boar Sus scrofa to Scotland: Are existing woodlands large enough to support minimum viable populations. Biological Conservation, 81(1), 77–89. doi:10.1016/S0006-3207(96)00134-6
* Jedrzejewska, B., Jedrzejewski, W., Bunevich, A. N., Milkowski, L., & Krasinski, Z. A. (1997). Factors shaping population densities and increase rates of ungulates in Bialowieza Primeval Forest (Poland and Belarus) in the 19th and 20th centuries. Acta Theriologica, 4(42). Retrieved from https://www.infona.pl/resource/bwmeta1.element.agro-article-f12b76e6-383a-4497-809a-9ca2f1205a93
* Kramer-Schadt, S., Fernández, N., Eisinger, D., Grimm, V., & Thulke, H.-H. (2009). Individual variations in infectiousness explain long-term disease persistence in wildlife populations. Oikos , 118(2), 199–208. Retrieved from https://onlinelibrary.wiley.com/doi/abs/10.1111/j.1600-0706.2008.16582.x
* Lange, M., Kramer-Schadt, S., Thulke, H.-H. (2016). Relevance of indirect transmission for wildlife disease surveillance. Frontiers in Veterinary Science 3, 110. doi: 10.3389/fvets.2016.00110
* Lange, M, Kramer-Schadt S, Thulke HH (2012a). Efficiency of spatio-temporal vaccination regimes in wildlife populations under different viral constraints. Veterinary Research, 43, 37.
* Lange, M, Kramer-Schadt, S., Blome, S., Beer, M., Thulke, H.-H. (2012b). Disease severity declines over time after a wild boar population has been affected by Classical Swine Fever – Legend or actual epidemiological process? Preventive Veterinary Medicine 106(2), 185-195.
* Leaper, R., Massei, G., Gorman, M. L., & Aspinall, R. (1999). The feasibility of reintroducing Wild Boar (Sus scrofa) to Scotland. Mammal Review, 29(4), 239–258. doi:10.1046/j.1365-2907.1999.2940239.x
* Liess, B. (1987). Pathogenesis and epidemiology of hog cholera. Annales de Recherches Veterinaires. Annals of Veterinary Research, 18(2), 139–145. Retrieved from https://www.ncbi.nlm.nih.gov/pubmed/3304111
* Melis, C., Szafranska, P. A., Jedrzejewska, B., & Barton, K. (2006). Biogeographical variation in the population density of wild boar (Sus scrofa) in western Eurasia. Journal of Biogeography, 33(5), 803–811. doi:10.1111/j.1365-2699.2006.01434.x
* Moennig, V., Floegel-Niesmann, G., & Greiser-Wilke, I. (2003). Clinical signs and epidemiology of classical swine fever: a review of new knowledge. Veterinary Journal , 165(1), 11–20. Retrieved from https://www.ncbi.nlm.nih.gov/pubmed/12618065
* Moretti, M. (2014). Birth distribution, structure and dynamics of a hunted mountain population of Wild boars (Sus scrofa L.), Ticino, Switzerland. Journal of Mountain Ecology, 3(0). Retrieved from http://mountainecology.org/index.php/me/article/view/110
* Rossi, S., Pol, F., Forot, B., Masse-Provin, N., Rigaux, S., Bronner, A., & Le Potier, M.-F. (2010). Preventive vaccination contributes to control classical swine fever in wild boar (Sus scrofa sp.). Veterinary Microbiology, 142(1-2), 99–107. doi:10.1016/j.vetmic.2009.09.050
* Sodeikat, G., & Pohlmeyer, K. (2003). Escape movements of family groups of wild boar Sus scrofa influenced by drive hunts in Lower Saxony, Germany. Wildlife Biology, 9(1), 43–49. doi:10.2981/wlb.2003.063
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="random" repetitions="200" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>DONE = 1</exitCondition>
    <metric>seed</metric>
    <metric>count turtles</metric>
    <metric>count turtles with [epi_stat = "esSusc"]</metric>
    <metric>count turtles with [epi_stat = "esTrans"]</metric>
    <metric>count turtles with [epi_stat = "esLeth"]</metric>
    <metric>new_trans</metric>
    <metric>new_leth</metric>
    <metric>count patches with [is_infected = 1]</metric>
    <metric>count patches with [is_infectious = 1]</metric>
    <metric>dist_inf</metric>
    <metric>week_inf_max</metric>
    <metric>week_release</metric>
    <metric>week_last</metric>
    <enumeratedValueSet variable="scenario">
      <value value="&quot;random&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="case_fatality" first="0" step="0.1" last="1"/>
    <steppedValueSet variable="mue" first="1" step="1" last="9"/>
    <enumeratedValueSet variable="t_trans">
      <value value="1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fert_red">
      <value value="0.625"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fetal_inf">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="fem_prob">
      <value value="0.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="run_years">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dist_disp">
      <value value="3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta_within">
      <value value="0.0208"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="release_fct">
      <value value="4.5"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="beta_between">
      <value value="0.00208"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="year_release">
      <value value="2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="age_blur">
      <value value="6"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="herd_prop">
      <value value="100"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="t_anti">
      <value value="12"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="longevity">
      <value value="11"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed_setup">
      <value value="&quot;BS&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="noise">
      <value value="true"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
